@@ -4,7 +4,7 @@ use strict;
 use Carp;
 use base qw(Unicode::Collate);
 
-our $VERSION = '0.58';
+our $VERSION = '0.60';
 
 use File::Spec;
 
@@ -13,9 +13,11 @@ my $KeyPath = File::Spec->catfile('allkeys.txt');
 my $PL_EXT  = '.pl';
 
 my %LocaleFile = map { ($_, $_) } qw(
-   af ca cs cy da eo es et fi fo fr haw is kl lv nn pl ro sk sl sv sw
+   af az ca cs cy da eo es et fi fil fo fr ha haw
+   is kl lt lv mt nn nso om pl ro sk sl sv sw tn tr vi wo yo
 );
    $LocaleFile{'default'}         = '';
+   $LocaleFile{'de__phonebook'}   = 'de_phone';
    $LocaleFile{'es__traditional'} = 'es_trad';
    $LocaleFile{'nb'} = 'nn';
 
@@ -24,6 +26,7 @@ sub _locale {
     if ($locale) {
 	$locale = lc $locale;
 	$locale =~ tr/\-\ \./_/;
+	$locale =~ s/_phone\z/_phonebook/;
 	$locale =~ s/_trad\z/_traditional/;
 	$LocaleFile{$locale} and return $locale;
 
@@ -39,7 +42,7 @@ sub getlocale {
     return shift->{accepted_locale};
 }
 
-sub _fetch_locale {
+sub _fetchpl {
     my $accepted = shift;
     my $f = $LocaleFile{$accepted};
     return if !$f;
@@ -60,7 +63,7 @@ sub new {
     }
     $hash{table} = $KeyPath;
 
-    my $href = _fetch_locale($hash{accepted_locale});
+    my $href = _fetchpl($hash{accepted_locale});
     while (my($k,$v) = each %$href) {
 	if (exists $hash{$k}) {
 	    croak "$k is reserved by $hash{locale}, can't be overwritten";
@@ -153,29 +156,63 @@ this method returns a string C<'default'> meaning no special tailoring.
       locale name       description
     ----------------------------------------------------------
       af                Afrikaans
+      az                Azerbaijani (Azeri)
       ca                Catalan
       cs                Czech
       cy                Welsh
       da                Danish
+      de__phonebook     German (umlaut as 'ae', 'oe', 'ue')
       eo                Esperanto
       es                Spanish
       es__traditional   Spanish ('ch' and 'll' as a grapheme)
       et                Estonian
       fi                Finnish
+      fil               Filipino
       fo                Faroese
       fr                French
+      ha                Hausa
       haw               Hawaiian
       is                Icelandic
       kl                Kalaallisut
+      lt                Lithuanian
       lv                Latvian
+      mt                Maltese
       nb                Norwegian Bokmal
       nn                Norwegian Nynorsk
+      nso               Northern Sotho
+      om                Oromo
       pl                Polish
       ro                Romanian
       sk                Slovak
       sl                Slovenian
       sv                Swedish
       sw                Swahili
+      tn                Tswana
+      tr                Turkish
+      vi                Vietnamese
+      wo                Wolof
+      yo                Yoruba
+
+=head1 INSTALL
+
+Installation of Unicode::Collate::Locale requires F<Collate/Locale.pm>,
+F<Collate/Locale/*.pm> and F<Collate/allkeys.txt>.  On building,
+Unicode::Collate::Locale doesn't require F<data/*.txt> and F<mklocale>.
+Tests for Unicode::Collate::Locale are named F<t/loc_*.t>.
+
+=head1 CAVEAT
+
+=over 4
+
+=item tailoring is not maximum
+
+If a certain letter is tailored, its equivalents are not always
+tailored as well as it. For example, even though W is tailored,
+fullwidth W (C<U+FF37>), W with acute (C<U+1E82>), etc. are not
+tailored. Thus the result may depend on whether source strings
+are normalized or not.
+
+=back
 
 =head1 AUTHOR
 
